# syncpipe

A userland implementation of [pipelines](https://github.com/valtech-nyc/proposal-fsharp-pipelines/blob/master/README.md). Handles synchronous operations only. Also sometimes known as 'waterfall'.

Useful to make `otherwise(deeply, nested(functionCalls(42))` a lot more readable. Also lets you combine object methods and stand-alone functions in a single chain of calls, instead of having to switch between wrapped calls and method calls, which gets messy very quickly with complex sequences of operations that you might want to split over multiple lines.

## License, donations, and other boilerplate

Licensed under either the [WTFPL](http://www.wtfpl.net/txt/copying/) or [CC0](https://creativecommons.org/publicdomain/zero/1.0/), at your choice. In practice, that means it's more or less public domain, and you can do whatever you want with it. Giving credit is *not* required, but still very much appreciated! I'd love to [hear from you](mailto:admin@cryto.net) if this module was useful to you.

Creating and maintaining open-source modules is a lot of work. A donation is also not required, but much appreciated! You can donate [here](http://cryto.net/~joepie91/donate.html).

## Example

A runnable version of this example can be found in `example.js` in the repository.

```js
const dateFns = require("date-fns");
const syncpipe = require("syncpipe");

function msUntilNextMinute() {
	return syncpipe(getTime(), [
		(_) => dateFns.addMinutes(_, 1),
		(_) => dateFns.setSeconds(_, 0),
		(_) => dateFns.setMilliseconds(_, 0),
		(_) => dateFns.differenceInMilliseconds(_, getTime())
	]);
}
```

The `_` is just a variable name here, you could call it anything you want - but giving it a consistent name will help with readability, as all of the arrow function bodies will be visually aligned.

## API

### syncpipe(value, functions)

Given a `value` and a series of `functions` that transform that value into a new value, runs those functions in sequence and returns the return value of the final function.

- __value:__ The initial value.
- __functions:__ An array of transformation functions, or a single transformation function (though that is somewhat pointless).


